@@ -3,6 +3,7 @@
 #include <string>
 #include <panda/memory.h>
 #include <panda/traits.h>
+#include <panda/string.h>
 #include <panda/string_view.h>
 #include <panda/exception.h>
 
@@ -184,4 +185,17 @@ inline void swap (Sv& lh, Sv& rh) { std::swap(lh.sv, rh.sv); }
 
 std::ostream& operator<< (std::ostream& os, const Sv& sv);
 
+
+struct PerlRuntimeException : std::exception {
+    Sv sv;
+
+    PerlRuntimeException(const Sv& sv) : sv(sv) {assert(sv);}
+
+    virtual const char* what() const noexcept override {
+        return SvPV_nolen(sv);
+    }
+};
+
+Sv eval (const panda::string& code);
+
 }
